@@ -7,7 +7,8 @@ from pddl_plus_parser.exporters import DomainExporter
 from pddl_plus_parser.lisp_parsers import DomainParser
 from pddl_plus_parser.models import Domain, Predicate, Action
 
-DUMMY_PREDICATE = Predicate(name="dummy-additional-predicate", signature={}, is_positive=True)
+DUMMY_PREDICATE_NAME = "dummy-additional-predicate"
+DUMMY_PREDICATE = Predicate(name=DUMMY_PREDICATE_NAME, signature={}, is_positive=True)
 
 
 class MultiAgentDomainsConverter:
@@ -42,7 +43,7 @@ class MultiAgentDomainsConverter:
             add_dummy_predicate = bool(random.randint(0, 1))
             if add_dummy_predicate:
                 self.logger.debug(f"Adding the dummy predicate to the action - {action.name}")
-                action.add_effects.add(DUMMY_PREDICATE)
+                action.delete_effects.add(DUMMY_PREDICATE)
 
     def locate_domains(self) -> Domain:
         """Locate only the domains when there is no need to also parse the problems."""
