@@ -50,6 +50,17 @@ TEST_PREDICATES_FOR_CONDITIONAL_DOMAIN = """((on ?c1 - card ?c2 - cardposition)
 )
 """
 
+TEST_PREDICATES_FOR_UNIVERSAL_QUANTIFIER_DOMAIN = """(
+    (origin ?person - passenger ?floor - floor)
+    (destin ?person - passenger ?floor - floor)
+    (above ?floor1 - floor  ?floor2 - floor)
+    (boarded ?person - passenger)
+    (served ?person - passenger)
+    (lift-at ?floor - floor)
+)
+"""
+
+
 TEST_TYPES_FOR_CONDITIONAL_DOMAIN = """(cardposition - object
     card_or_tableau - cardposition
     card - card_or_tableau
@@ -57,6 +68,9 @@ TEST_TYPES_FOR_CONDITIONAL_DOMAIN = """(cardposition - object
     deal - cardposition
 )"""
 
+TYPES_FOR_UNIVERSAL_CONDITIONAL_DOMAIN = """(passenger - object
+          floor - object)"""
+
 TEST_CONSTANTS_FOR_CONDITIONAL_DOMAIN = """(discard - cardposition)"""
 
 SPIDER_DOMAIN_PATH = Path(CWD, "domain_spider.pddl")
